# MessageUserSpec

Configuration of messaging endpoints on user
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**preferred** | [**MessageEndpointType**](MessageEndpointType.md) |  | [optional] 
**endpoints** | [**list[MessageEndpoint]**](MessageEndpoint.md) | The list of the user&#39;s endpoints | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


